@@ -94,8 +94,8 @@ proc ::pd_guiprefs::init {} {
             # ------------------------------------------------------------------------------
             # macOS: read a plist file using the 'defaults' command
             #
-            proc ::pd_guiprefs::get_config {adomain {akey} {arr false}} {
-                if {![catch {exec defaults read $adomain $akey} conf]} {
+            proc ::pd_guiprefs::get_config {domain key {arr false}} {
+                if {![catch {exec defaults read $domain $key} conf]} {
                     if {$arr} {
                         set conf [plist_array_to_tcl_list $conf]
                     }
@@ -103,11 +103,11 @@ proc ::pd_guiprefs::init {} {
                     # value not found, so set empty value
                     if {$arr} {
                         # initialize w/ empty array for NSRecentDocuments, etc
-                        exec defaults write $adomain $akey -array
+                        exec defaults write $domain $key -array
                         set conf {}
                     } else {
                         # not an array
-                        exec defaults write $adomain $akey ""
+                        exec defaults write $domain $key ""
                         set conf ""
                     }
                 }
@@ -117,26 +117,46 @@ proc ::pd_guiprefs::init {} {
             # macOS: write configs to plist file using the 'defaults' command
             # if $arr is true, we write an array
             #
-            proc ::pd_guiprefs::write_config {data {adomain} {akey} {arr false}} {
+            proc ::pd_guiprefs::write_config {data domain key {arr false}} {
                 if {$arr} {
                     # FIXME empty and write again so we don't lose the order
-                    if {[catch {exec defaults write $adomain $akey -array} errorMsg]} {
-                        puts "write_config $akey: $errorMsg\n"
+                    if {[catch {exec defaults write $domain $key -array} errorMsg]} {
+                        puts "write_config $key: $errorMsg\n"
                     }
                     foreach item $data {
                         set escaped [escape_for_plist $item]
-                        if {[catch {eval exec defaults write $adomain $akey -array-add $escaped} errorMsg]} {
-                            puts "write_config $akey: $errorMsg\n"
+                        if {[catch {eval exec defaults write $domain $key -array-add $escaped} errorMsg]} {
+                            puts "write_config $key: $errorMsg\n"
                         }
                     }
                 } else {
                     set escaped [escape_for_plist $data]
-                    if {[catch {exec defaults write $adomain $akey $escaped} errorMsg]} {
-                        puts "write_config $akey: $errorMsg\n"
+                    if {[catch {exec defaults write $domain $key $escaped} errorMsg]} {
+                        puts "write_config $key: $errorMsg\n"
                     }
                 }
                 return
             }
+            # ------------------------------------------------------------------------------
+            # macOS: delete config from registry (if $key is empty, delete the entire $domain)
+            proc ::pd_guiprefs::delete_config {{domain {}} {key {}}} {
+                if { "${domain}" == "" } { set domain ${::pd_guiprefs::domain} }
+                if { "${domain}" == "" } {
+                    ::pdwindow::error [concat "delete_config: " [_ "refusing to delete empty domain" ] "\n"]
+                    return 0
+                }
+                if {[catch {
+                    if {$key == ""} {
+                        exec defaults delete ${domain}
+                    } {
+                        exec defaults delete ${domain} ${key}
+                    }
+                } errorMsg] } {
+                    ::pdwindow::error "delete_config ${domain}::${key}: $errorMsg\n"
+                    return 0
+                }
+                return 1
+            }
 
             # Disable window state saving by default for 10.7+ as there is a chance
             # pd will hang on start due to conflicting patch resources until the state
@@ -147,6 +167,9 @@ proc ::pd_guiprefs::init {} {
 
             # Disable Character Accent Selector popup so key repeat works for all keys.
             exec defaults write $::pd_guiprefs::domain ApplePressAndHoldEnabled -bool false
+
+            # Disable Dark Mode for 10.14+
+            exec defaults write $::pd_guiprefs::domain NSRequiresAquaSystemAppearance -bool true
         }
         "registry" {
             # windows uses registry
@@ -156,10 +179,10 @@ proc ::pd_guiprefs::init {} {
             # ------------------------------------------------------------------------------
             # w32: read in the registry
             #
-            proc ::pd_guiprefs::get_config {adomain {akey} {arr false}} {
+            proc ::pd_guiprefs::get_config {domain key {arr false}} {
                 package require registry
-                set adomain [join [list ${::pd_guiprefs::registrypath} ${adomain}] \\]
-                if {![catch {registry get ${adomain} $akey} conf]} {
+                set domain [join [list ${::pd_guiprefs::registrypath} ${domain}] \\]
+                if {![catch {registry get ${domain} $key} conf]} {
                     return [expr {$conf}]
                 }
                 return {}
@@ -168,21 +191,43 @@ proc ::pd_guiprefs::init {} {
             # w32: write configs to registry
             # if $arr is true, we write an array
             #
-            proc ::pd_guiprefs::write_config {data {adomain} {akey} {arr false}} {
+            proc ::pd_guiprefs::write_config {data domain key {arr false}} {
                 package require registry
                 # FIXME: ugly
-                set adomain [join [list ${::pd_guiprefs::registrypath} ${adomain}] \\]
+                set domain [join [list ${::pd_guiprefs::registrypath} ${domain}] \\]
                 if {$arr} {
-                    if {[catch {registry set ${adomain} $akey $data multi_sz} errorMsg]} {
-                        ::pdwindow::error "write_config $data $akey: $errorMsg\n"
+                    if {[catch {registry set ${domain} $key $data multi_sz} errorMsg]} {
+                        ::pdwindow::error "write_config $data $key: $errorMsg\n"
                     }
                 } else {
-                    if {[catch {registry set ${adomain} $akey $data sz} errorMsg]} {
-                        ::pdwindow::error "write_config $data $akey: $errorMsg\n"
+                    if {[catch {registry set ${domain} $key $data sz} errorMsg]} {
+                        ::pdwindow::error "write_config $data $key: $errorMsg\n"
                     }
                 }
                 return
             }
+            # ------------------------------------------------------------------------------
+            # w32: delete config from registry (if $key is empty, delete the entire $domain)
+            proc ::pd_guiprefs::delete_config {{domain {}} {key {}}} {
+                if { "${domain}" == "" } { set domain ${::pd_guiprefs::domain} }
+                if { "${domain}" == "" } {
+                    ::pdwindow::error [concat "delete_config: " [_ "refusing to delete empty domain" ] "\n"]
+                    return 0
+                }
+                package require registry
+                set domain [join [list ${::pd_guiprefs::registrypath} ${domain}] \\]
+                if {[catch {
+                    if {$key == ""} {
+                        registry delete ${domain}
+                    } {
+                        registry delete ${domain} ${key}
+                    }
+                } errorMsg] } {
+                    ::pdwindow::error "delete_config ${domain}::${key}: $errorMsg\n"
+                    return 0
+                }
+                return 1
+            }
         }
         "file" {
             set ::pd_guiprefs::recentfiles_key "recentfiles"
@@ -191,15 +236,41 @@ proc ::pd_guiprefs::init {} {
             # ------------------------------------------------------------------------------
             # linux: read a config file and return its lines splitted.
             #
-            proc ::pd_guiprefs::get_config {adomain {akey} {arr false}} {
-                return [::pd_guiprefs::get_config_file $adomain $akey $arr]
+            proc ::pd_guiprefs::get_config {domain key {arr false}} {
+                return [::pd_guiprefs::get_config_file $domain $key $arr]
             }
             # ------------------------------------------------------------------------------
             # linux: write configs to USER_APP_CONFIG_DIR
             # $arr is true if the data needs to be written in an array
             #
-            proc ::pd_guiprefs::write_config {data {adomain} {akey} {arr false}} {
-                return [::pd_guiprefs::write_config_file $data $adomain $akey $arr]
+            proc ::pd_guiprefs::write_config {data domain key {arr false}} {
+                return [::pd_guiprefs::write_config_file $data $domain $key $arr]
+            }
+            # ------------------------------------------------------------------------------
+            # linux: delete config from registry (if $key is empty, delete the entire $domain)
+            proc ::pd_guiprefs::delete_config {{domain {}} {key {}}} {
+                if { "${domain}" == "" } { set domain ${::pd_guiprefs::domain} }
+                if { "${domain}" == "" } {
+                    ::pdwindow::error [concat "delete_config: " [_ "refusing to delete empty domain" ] "\n"]
+                    return 0
+                }
+                set fullconfigdir [file join ${::pd_guiprefs::configdir} ${domain}]
+                set filename [file join ${fullconfigdir} ${key}.conf]
+
+                if {[file isdirectory $fullconfigdir] != 1} {
+                    return 0
+                }
+                if {[catch {
+                    if {$key == ""} {
+                        file delete -force $fullconfigdir
+                    } {
+                        file delete $filename
+                    }
+                } errorMsg] } {
+                    ::pdwindow::error "delete_config ${domain}::${key}: $errorMsg\n"
+                    return 0
+                }
+                return 1
             }
         }
         default {
@@ -220,8 +291,8 @@ proc ::pd_guiprefs::init {} {
 # ------------------------------------------------------------------------------
 # read a config file and return its lines splitted.
 #
-proc ::pd_guiprefs::get_config_file {adomain {akey} {arr false}} {
-    set filename [file join ${::pd_guiprefs::configdir} ${adomain} ${akey}.conf]
+proc ::pd_guiprefs::get_config_file {domain key {arr false}} {
+    set filename [file join ${::pd_guiprefs::configdir} ${domain} ${key}.conf]
     set conf {}
     if {
         [file exists $filename] == 1
@@ -239,13 +310,13 @@ proc ::pd_guiprefs::get_config_file {adomain {akey} {arr false}} {
 # write configs to USER_APP_CONFIG_DIR
 # $arr is true if the data needs to be written in an array
 #
-proc ::pd_guiprefs::write_config_file {data {adomain} {akey} {arr false}} {
-    ::pd_guiprefs::prepare_domain ${adomain}
+proc ::pd_guiprefs::write_config_file {data domain key {arr false}} {
+    ::pd_guiprefs::prepare_domain ${domain}
     # right now I (yvan) assume that data are just \n separated, i.e. no keys
     set data [join $data "\n"]
-    set filename [file join ${::pd_guiprefs::configdir} ${adomain} ${akey}.conf]
+    set filename [file join ${::pd_guiprefs::configdir} ${domain} ${key}.conf]
     if {[catch {set fl [open $filename w]} errorMsg]} {
-        ::pdwindow::error "write_config $data $akey: $errorMsg\n"
+        ::pdwindow::error "write_config $data $key: $errorMsg\n"
     } else {
         puts -nonewline $fl $data
         close $fl
@@ -257,12 +328,16 @@ proc ::pd_guiprefs::write_config_file {data {adomain} {akey} {arr false}} {
 #################################################################
 
 ## these are stubs that will be overwritten in ::pd_guiprefs::init()
-proc ::pd_guiprefs::write_config {data {adomain} {akey} {arr false}} {
+proc ::pd_guiprefs::write_config {data domain key {arr false}} {
     ::pdwindow::error "::pd_guiprefs::write_config not implemented for $::platform\n"
 }
-proc ::pd_guiprefs::get_config {adomain {akey} {arr false}} {
+proc ::pd_guiprefs::get_config {domain key {arr false}} {
     ::pdwindow::error "::pd_guiprefs::get_config not implemented for $::platform\n"
 }
+proc ::pd_guiprefs::delete_config {{domain {}} {key {}}} {
+    ::pdwindow::error "::pd_guiprefs::delete_config not implemented for $::platform\n"
+    return 0
+}
 
 # simple API (with a default domain)
 proc ::pd_guiprefs::write {key data {arr false} {domain {}}} {
@@ -336,9 +411,9 @@ proc ::pd_guiprefs::prepare_domain {{domain {}}} {
 # ------------------------------------------------------------------------------
 # convenience proc to init prefs value, returns default if not found
 #
-proc ::pd_guiprefs::init_config {adomain akey {default ""} {arr false}} {
+proc ::pd_guiprefs::init_config {domain key {default ""} {arr false}} {
     set conf ""
-    catch {set conf [::pd_guiprefs::get_config $adomain $akey $arr]}
+    catch {set conf [::pd_guiprefs::get_config $domain $key $arr]}
     if {$conf eq ""} {set conf $default}
     return $conf
 }
